@@ -10,13 +10,12 @@ from web_framework_v2.decorator import Decorator
 class JwtSecurity(Decorator, ABC):
     _SECRET = "secret_key_temporary"
 
-    def __init__(self, on_fail=lambda request, response: None, allow_access_on_error=False):
+    def __init__(self, on_fail=lambda request, response: None):
         """
         Base class of JWT security
         :param on_fail: called when security check fails.
         """
         self.on_fail = on_fail
-        self.allow_access_on_error = allow_access_on_error
 
     @staticmethod
     def secret():
@@ -28,14 +27,17 @@ class JwtSecurity(Decorator, ABC):
 
     @staticmethod
     def decode_token(token):
-        return jwt.decode(token, JwtSecurity.secret(), algorithms=["HS256"])
+        try:
+            return jwt.decode(token, JwtSecurity.secret(), algorithms=["HS256"])
+        except:
+            return None
 
     @staticmethod
     def decode_request(request):
-        return jwt.decode(request.headers["Authorization"][8:], JwtSecurity.secret(), algorithms=["HS256"])
+        return JwtSecurity.decode_token(request.headers["Authorization"][8:])
 
     @staticmethod
-    def create_token(self, data, expiration_seconds: int):
+    def create_token(data, expiration_seconds: int):
         data["exp"] = datetime.now(tz=timezone.utc).timestamp() + expiration_seconds
         return jwt.encode(data, JwtSecurity.secret())
 
@@ -45,8 +47,8 @@ class JwtTokenFactory(JwtSecurity, ABC):
     Authenticates and creates a new token using request and request body
     """
 
-    def __init__(self, on_fail=lambda request, response: None, allow_access_on_error=False, expiration_time=60 * 30):
-        super().__init__(on_fail=on_fail, allow_access_on_error=allow_access_on_error)
+    def __init__(self, on_fail=lambda request, response: None, expiration_time=60 * 30):
+        super().__init__(on_fail=on_fail)
         self.expiration_time = expiration_time
 
     def should_execute_endpoint(self, request, request_body) -> Tuple[bool, object, object]:
@@ -69,14 +71,10 @@ class JwtTokenAuth(JwtSecurity, ABC):
     """
 
     def should_execute_endpoint(self, request, request_body) -> Tuple[bool, object, object]:
-        authentication_result, fail_data = self.authenticate(request, request_body)
-        try:
-            return authentication_result, JwtSecurity.decode_request(request), fail_data
-        except:
-            try:
-                return self.authenticate(request, request_body), None, fail_data
-            except:
-                return self.allow_access_on_error, None, fail_data
+        decoded_token = JwtSecurity.decode_request(request)
+        authentication_result, fail_data = self.authenticate(request, request_body, decoded_token)
 
-    def authenticate(self, request, request_body) -> (bool, object):
+        return authentication_result, decoded_token, fail_data
+
+    def authenticate(self, request, request_body, decoded_token) -> (bool, object):
         raise NotImplementedError(f"Must implement authentication for {type(self)}!")
